@@ -25,7 +25,6 @@
 #include "panel-gconf.h"
 #include "panel-config-global.h"
 #include "session.h"
-#include "status.h"
 #include "panel-applet-frame.h"
 
 #define SMALL_ICON_SIZE 20
@@ -49,7 +48,6 @@ static GConfEnumStringPair object_type_enum_map [] = {
 	{ APPLET_LAUNCHER, "launcher-object" }, 
 	{ APPLET_EMPTY,    "empty-object" },
 	{ APPLET_LOCK,     "lock-object" },
-	{ APPLET_STATUS,   "status-object" },
 	{ APPLET_BONOBO,   "bonobo-applet" },
 };
 
@@ -97,14 +95,13 @@ panel_applet_clean_gconf (AppletInfo *info,
 			GCONF_VALUE_STRING, NULL);
 
         for (l = id_list; l; l = l->next)
-                if (!strcmp (info->gconf_key, (char *) l->data))
+                if (strcmp (info->gconf_key, (char *) l->data) == 0)
                         break;
 
         if (l) {
-                id_list = g_slist_remove_link (id_list, l);
-
 		g_free (l->data);
-		g_slist_free (l);
+		l->data = NULL;
+                id_list = g_slist_delete_link (id_list, l);
 
                 gconf_client_set_list (client, temp_key, GCONF_VALUE_STRING, id_list, NULL);
 
@@ -144,9 +141,6 @@ panel_applet_clean (AppletInfo *info,
 	if (info->widget) {
 		GtkWidget *widget = info->widget;
 
-		if (info->type == APPLET_STATUS)
-			status_applet_put_offscreen (info->data);
-
 		info->widget = NULL;
 		gtk_widget_destroy (widget);
 	}
@@ -197,7 +191,7 @@ applet_callback_callback(GtkWidget *widget, gpointer data)
 		if (strcmp (menu->name, "properties") == 0) {
 			launcher_properties (menu->info->data);
 		} else if (strcmp (menu->name, "help") == 0) {
-			panel_show_help ("launchers", NULL);
+			panel_show_help ("wgospanel.xml", "gospanel-16");
 		} else if (strcmp (menu->name, "help_on_app") == 0) {
 			Launcher * launcher = menu->info->data;
 			if (launcher->ditem != NULL) {
@@ -220,7 +214,7 @@ applet_callback_callback(GtkWidget *widget, gpointer data)
 			g_assert(drawer);
 			panel_config(drawer->drawer);
 		} else if (strcmp (menu->name, "help") == 0) {
-			panel_show_help ("drawers", NULL);
+			panel_show_help ("wgospanel.xml", "gospanel-18");
 		}
 		break;
 	case APPLET_MENU:
@@ -234,10 +228,7 @@ applet_callback_callback(GtkWidget *widget, gpointer data)
 				g_free (tmp[0]);
 			}
 		} else if (strcmp (menu->name, "help") == 0) {
-			Menu *menu2 = menu->info->data;
-			char *page;
-			page = menu2->main_menu ? "mainmenu" : "menus";
-			panel_show_help (page, NULL);
+			panel_show_help ("wgospanel.xml", "gospanel-37");
 		}
 		break;
 	case APPLET_LOCK: {
@@ -255,10 +246,10 @@ applet_callback_callback(GtkWidget *widget, gpointer data)
 		char *command = NULL;
 		gboolean freeit = FALSE;
 		if (strcmp (menu->name, "help") == 0)
-			panel_show_help ("specialobjects", "LOCKBUTTON");
-		else if (!strcmp (menu->name, "restart")) {
+			panel_show_help ("wgospanel.xml", "gospanel-21");
+		else if (strcmp (menu->name, "restart") == 0) {
 			command = "xscreensaver-command -exit ; xscreensaver &";
-		} else if (!strcmp (menu->name, "prefs")) {
+		} else if (strcmp (menu->name, "prefs") == 0) {
 			command = "xscreensaver-demo";
 		} else {
 			command = g_strdup_printf ("xscreensaver-command -%s",
@@ -273,11 +264,7 @@ applet_callback_callback(GtkWidget *widget, gpointer data)
 	}
 	case APPLET_LOGOUT:
 		if (strcmp (menu->name, "help") == 0)
-			panel_show_help ("specialobjects", "LOGOUTBUTTON");
-		break;
-	case APPLET_STATUS:
-		if (strcmp (menu->name, "help") == 0)
-			panel_show_help ("specialobjects", "STATUSDOC");
+			panel_show_help ("wgospanel.xml", "gospanel-20");
 		break;
 	case APPLET_BONOBO:
 		/*
@@ -309,7 +296,7 @@ panel_applet_get_callback (GList      *user_menu,
 	for (l = user_menu; l; l = l->next) {
 		AppletUserMenu *menu = l->data;
 
-		if (!strcmp (menu->name, name))
+		if (strcmp (menu->name, name) == 0)
 			return menu;
 	}
 
@@ -567,10 +554,10 @@ panel_applet_create_menu (AppletInfo *info)
 	return menu;
 }
 
-static void
-applet_menu_set_data_recursively (GtkMenu     *menu,
-				  const gchar *key,
-				  gpointer     data)
+void
+panel_applet_menu_set_recurse (GtkMenu     *menu,
+			       const gchar *key,
+			       gpointer     data)
 {
 	GList *children;
 	GList *l;
@@ -583,7 +570,8 @@ applet_menu_set_data_recursively (GtkMenu     *menu,
 		GtkWidget *submenu = GTK_MENU_ITEM (l->data)->submenu;
 
 		if (submenu)
-			applet_menu_set_data_recursively (GTK_MENU (submenu), key, data);
+			panel_applet_menu_set_recurse (
+				GTK_MENU (submenu), key, data);
 	}
 
 	g_list_free (children);
@@ -611,9 +599,9 @@ applet_show_menu (AppletInfo     *info,
 
 	info->menu_age = 0;
 
-	applet_menu_set_data_recursively (GTK_MENU (info->menu),
-					  "menu_panel",
-					  info->widget->parent);
+	panel_applet_menu_set_recurse (GTK_MENU (info->menu),
+				       "menu_panel",
+				       info->widget->parent);
 
 	if (!GTK_WIDGET_REALIZED (info->menu))
 		gtk_widget_show (info->menu);
@@ -775,12 +763,14 @@ panel_applet_load_idle_handler (gpointer dummmy)
 {
 	PanelAppletToLoad *applet;
 
-	if (!panel_applets_to_load)
+	if (panel_applets_to_load == NULL)
 		return FALSE;
 
 	applet = (PanelAppletToLoad *) panel_applets_to_load->data;
+	panel_applets_to_load->data = NULL;
 	panel_applets_to_load =
-		g_slist_remove (panel_applets_to_load, applet);
+		g_slist_delete_link (panel_applets_to_load,
+				     panel_applets_to_load);
 
 	panel_applet_frame_load_from_gconf (
 			applet->panel_widget,
@@ -853,10 +843,8 @@ panel_applet_load_from_unique_id (AppletType   type,
 		return;
 	}
 
-	/*
-	 * A hack from the old panel to make sure the applet is on the right
-	 */
-	position += right_stick ? G_MAXINT/2 : 0;
+	if (right_stick)
+		position = panel_widget->size - position;
 
 	switch (applet_type) {
 	case APPLET_BONOBO: {
@@ -893,9 +881,6 @@ panel_applet_load_from_unique_id (AppletType   type,
 	case APPLET_LOCK:
 		load_lock_applet (panel_widget, position, TRUE, unique_id);
 		break;
-	case APPLET_STATUS:
-		load_status_applet (panel_widget, position, TRUE, unique_id);
-		break;
 	default:
 		break;
 	}
@@ -961,6 +946,8 @@ panel_applet_save_position (AppletInfo *applet_info,
 	GConfClient  *client;
 	const char   *profile;
 	const char   *temp_key;
+	gboolean      right_stick;
+	int           position;
 
 	g_return_if_fail (applet_info != NULL);
 
@@ -981,17 +968,23 @@ panel_applet_save_position (AppletInfo *applet_info,
 	client  = panel_gconf_get_client ();
 	profile = panel_gconf_get_profile ();
 
+	right_stick = panel_applet_get_right_stick (applet_info);
+	temp_key = panel_applet_get_full_gconf_key (
+			applet_info->type, profile, gconf_key, "panel_right_stick");
+	gconf_client_set_bool (client, temp_key, right_stick, NULL);
+
+	position = panel_applet_get_position (applet_info);
+	if (right_stick)
+		position = PANEL_WIDGET (applet_info->widget->parent)->size - position;
+
 	temp_key = panel_applet_get_full_gconf_key (
 			applet_info->type, profile, gconf_key, "position");
-	gconf_client_set_int (client, temp_key, panel_applet_get_position (applet_info), NULL);
+	gconf_client_set_int (client, temp_key, position, NULL);
 
 	temp_key = panel_applet_get_full_gconf_key (
 			applet_info->type, profile, gconf_key, "panel_id");
 	gconf_client_set_string (client, temp_key, panel_applet_get_panel_id (applet_info), NULL);
 
-	temp_key = panel_applet_get_full_gconf_key (
-			applet_info->type, profile, gconf_key, "panel_right_stick");
-	gconf_client_set_bool (client, temp_key, panel_applet_get_right_stick (applet_info), NULL);
 
 	gconf_client_suggest_sync (client, NULL);
 }
@@ -1018,7 +1011,7 @@ panel_applet_save_to_gconf (AppletInfo *applet_info)
 		applet_info->gconf_key = gconf_unique_key ();
 
 	for (l = id_list; l; l = l->next)
-		if (!strcmp (applet_info->gconf_key, (char *) l->data))
+		if (strcmp (applet_info->gconf_key, (char *) l->data) == 0)
 			break;
 
 	if (!l) {
@@ -1057,7 +1050,6 @@ panel_applet_save_to_gconf (AppletInfo *applet_info)
 		break;
 	case APPLET_LOGOUT: /* no object specific stuff to save */
 	case APPLET_LOCK:
-	case APPLET_STATUS:
 	default:
 		break;
 	}
